==> qip-catalog-library-0.1.1-sources.jar: org/qubership/integration/platform/catalog/persistence/configs/entity/AbstractLabel.java <==
/*
 * Copyright 2024-2025 NetCracker Technology Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.qubership.integration.platform.catalog.persistence.configs.entity;

import com.fasterxml.jackson.annotation.JsonValue;
import jakarta.persistence.Column;
import jakarta.persistence.Id;
import jakarta.persistence.MappedSuperclass;
import lombok.*;
import lombok.experimental.SuperBuilder;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.hibernate.proxy.HibernateProxy;

import java.io.Serializable;
import java.util.Objects;
import java.util.UUID;

@Getter
@Setter
@Slf4j
@SuperBuilder
@MappedSuperclass
@NoArgsConstructor
@AllArgsConstructor
public abstract class AbstractLabel implements Serializable {

    @Id
    @Builder.Default
    protected String id = UUID.randomUUID().toString();

    @Column
    protected String name;

    @Column
    protected boolean technical;


    protected AbstractLabel(final String name) {
        this(name, false);
    }

    protected AbstractLabel(final String name, final boolean technical) {
        this();
        this.name = name;
        this.technical = technical;
    }

    @Override
    public boolean equals(Object o) {
        return equals(o, true);
    }

    public boolean equals(Object o, boolean strict) {
        if (this == o) return true;
        if (o == null) return false;
        Class<?> oEffectiveClass = o instanceof HibernateProxy ? ((HibernateProxy) o).getHibernateLazyInitializer().getPersistentClass() : o.getClass();
        Class<?> thisEffectiveClass = this instanceof HibernateProxy ? ((HibernateProxy) this).getHibernateLazyInitializer().getPersistentClass() : this.getClass();
        if (thisEffectiveClass != oEffectiveClass) return false;
        AbstractLabel that = (AbstractLabel) o;
        return (!strict || StringUtils.equals(this.getId(), that.getId())) &&
                Objects.equals(name, that.name) &&
                Objects.equals(technical, that.technical);
    }

    @Override
    public int hashCode() {
        return Objects.hash(name, technical);
    }

    @JsonValue
    public String serialize() {
        return name;
    }
}

==> qip-catalog-library-0.1.7-sources.jar: org/qubership/integration/platform/catalog/persistence/configs/entity/AbstractLabel.java <==
/*
 * Copyright 2024-2025 NetCracker Technology Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.qubership.integration.platform.catalog.persistence.configs.entity;

import com.fasterxml.jackson.annotation.JsonValue;
import jakarta.persistence.Column;
import jakarta.persistence.Id;
import jakarta.persistence.MappedSuperclass;
import lombok.*;
import lombok.experimental.SuperBuilder;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.hibernate.proxy.HibernateProxy;

import java.io.Serializable;
import java.util.Objects;
import java.util.UUID;

@Getter
@Setter
@Slf4j
@SuperBuilder
@MappedSuperclass
@NoArgsConstructor
@AllArgsConstructor
public abstract class AbstractLabel implements Serializable {

    @Id
    @Builder.Default
    protected String id = UUID.randomUUID().toString();

    @Column
    protected String name;

    @Column
    protected boolean technical;


    protected AbstractLabel(final String name) {
        this(name, false);
    }

    protected AbstractLabel(final String name, final boolean technical) {
        this();
        this.name = name;
        this.technical = technical;
    }

    @Override
    public boolean equals(Object o) {
        return equals(o, true);
    }

    public boolean equals(Object o, boolean strict) {
        if (this == o) {
            return true;
        }
        if (o == null) {
            return false;
        }
        Class<?> oEffectiveClass = o instanceof HibernateProxy ? ((HibernateProxy) o).getHibernateLazyInitializer().getPersistentClass() : o.getClass();
        Class<?> thisEffectiveClass = this instanceof HibernateProxy ? ((HibernateProxy) this).getHibernateLazyInitializer().getPersistentClass() : this.getClass();
        if (thisEffectiveClass != oEffectiveClass) {
            return false;
        }
        AbstractLabel that = (AbstractLabel) o;
        return (!strict || StringUtils.equals(this.getId(), that.getId()))
                && Objects.equals(name, that.name)
                && Objects.equals(technical, that.technical);
    }

    @Override
    public int hashCode() {
        return Objects.hash(name, technical);
    }

    @JsonValue
    public String serialize() {
        return name;
    }
}
